﻿PoisonReminderFu = AceLibrary("AceAddon-2.0"):new("FuBarPlugin-2.0", "AceDB-2.0", "AceEvent-2.0", "AceConsole-2.0")
local Tablet = AceLibrary("Tablet-2.0")
local Crayon = AceLibrary("Crayon-2.0")

PoisonReminderFu.Menu = {
type = "group",
args = {
	["Set Preset"] = {
		type = "text",
		order = 3,
		name = "Set Preset",
		desc = "Set the preset to re-apply",
		get = "GetPreset",
		set = "SetPreset",
		validate = {"Instant Poison", "Crippling Poison", "Deadly Poison", "Mind-numbing Poison", "Wound Poison",
					"Consecrated Sharpening Stone", "Elemental Sharpening Stone", "Coarse Sharpening Stone",
					"Dense Sharpening Stone", "Heavy Sharpening Stone", "Rough Sharpening Stone", "Solid Sharpening Stone"},
		hidden = "GetLast",
	},
	["Use Preset"] = {
		type = "toggle",
		name = "Use Preset",
		order = 2,
		desc = "Use a preset poison for re-applications",
		get = function() return not PoisonReminderFu:GetLast() end,
		set = "SetLast",
		map = { [false] = "Disabled", [true] = "Enabled" },
	},
	["Use Last Applied"] = {
		type = "toggle",
		name = "Use Last Applied",
		order = 1,
		desc = "Use a Last Applied poison for re-applications",
		set = "SetLast",
		get = "GetLast",
		map = { [false] = "Disabled", [true] = "Enabled" },
	},
	["Keep Asking"] = {
		type = "toggle",
		name = "Keep Asking",
		order = 4,
		desc = "Keep asking for re-apply every 5mins",
		set = "SetKeep",
		get = "GetKeep",
		map = { [false] = "Disabled", [true] = "Enabled" },
	},
	Classes = {
		type = 'toggle',
		order = 11,
		name = "Classes",
	    desc = "Enable/Dissable auto enable for Rogues/dissable for other classes",
	    get = "GetLoad",
	    set = "SetLoad",
		map = { [false] = "Disabled", [true] = "Enabled" }
		},
	}
}

PoisonReminderFu.hasIcon = "Interface\\Icons\\Ability_Rogue_DualWeild"
PoisonReminderFu.defaultMinimapPosition = 180
PoisonReminderFu.OnMenuRequest = PoisonReminderFu.Menu
PoisonReminderFu.hideWithoutStandby = true

function PoisonReminderFu:OnInitialize()
self:RegisterDB("PoisonReminderFuDB")
self:RegisterDefaults('profile', {class = true, last = true, preset = "Instant Poison", keep = true})
self.revision = tonumber(string.sub("$Rev: 23237 $", 7, -3))
self.version = PoisonReminderFu.version .. " |cffff8888r"..PoisonReminderFu.revision.."|r"
if self.db.profile.class then
	local playerClass, englishClass = UnitClass("player");
	if (englishClass == "ROGUE") then
	self:ToggleActive(true)
	else
	self:ToggleActive(false)
	end
end
self:RegisterChatCommand({"/PoisonReminderFu", "/pmf"}, self.Menu)
end

function PoisonReminderFu:OnEnable()
self:ScheduleRepeatingEvent(self.Update, 1, self)
self:ScheduleRepeatingEvent(self.PoisonUpdate, 1, self)
self:RegisterEvent("CHAT_MSG_SPELL_ITEM_ENCHANTMENTS", "CastPoison")
self.HasMainHand = true
self.HasOffHand = true
end

function PoisonReminderFu:GetKeep()
return self.db.profile.keep
end

function PoisonReminderFu:SetKeep()
self.db.profile.keep = not self.db.profile.keep
end

function PoisonReminderFu:GetLoad()
return self.db.profile.class
end

function PoisonReminderFu:SetLoad()
self.db.profile.class = not self.db.profile.class
end 

function PoisonReminderFu:GetLast()
return self.db.profile.last
end

function PoisonReminderFu:SetLast()
self.db.profile.last = not self.db.profile.last
end

function PoisonReminderFu:GetPreset()
return self.db.profile.preset
end

function PoisonReminderFu:SetPreset(v)
self.db.profile.preset = v
end

function PoisonReminderFu:OnTooltipUpdate()
	local cat = Tablet:AddCategory(
		'columns', 2,
		'child_textR', 1,
		'child_textG', 1,
		'child_textB', 0
	)
	local r, g, b = PoisonReminderFu:GetColor(16)
	cat:AddLine(
		'text', "Main Hand",
		'text2', PoisonReminderFu:GetText(16)
	)
	local r, g, b = PoisonReminderFu:GetColor(17)
	cat:AddLine(
		'text', "Off Hand",
		'text2', PoisonReminderFu:GetText(17)
	)
end 

function PoisonReminderFu:GetText(wep)
local hasMainHandEnchant, mainHandExpiration, mainHandCharges, hasOffHandEnchant, offHandExpiration, offHandCharges = GetWeaponEnchantInfo()
if wep == 16 then
	if not hasMainHandEnchant then return "|cffff0000No Poison!|r" end 
	local time = PoisonReminderFu:time(mainHandExpiration/1000)
	if mainHandCharges > 1 then time = time.." ("..format("|cff%s%d|r",Crayon:GetThresholdHexColor(mainHandCharges, 10, 30, 70, 100, 120) ,mainHandCharges).." charges)" end
	return time
elseif wep == 17 then
	if not hasOffHandEnchant then return "|cffff0000No Poison!|r" end 
	local time = PoisonReminderFu:time(offHandExpiration/1000)
	if offHandCharges > 1 then time = time.." ("..format("|cff%s%d|r",Crayon:GetThresholdHexColor(offHandCharges, 10, 30, 70, 100, 120) ,offHandCharges).." charges)" end
	return time
end
end	

function PoisonReminderFu:GetColor(wep)
local r, g, b
local hasMainHandEnchant, mainHandExpiration, mainHandCharges, hasOffHandEnchant, offHandExpiration, offHandCharges = GetWeaponEnchantInfo()
if wep == 16 then
	if not hasMainHandEnchant then r, g, b = 1, 0, 0 return r, g, b end
	r, g, b = 0, 1, 0
	return r, g, b
elseif wep == 17 then
	if not hasOffHandEnchant then r, g, b = 1, 0, 0 return r, g, b end
	r, g, b = 0, 1, 0
	return r, g, b
end
end

function PoisonReminderFu:time(t)
	local m = floor(t/60)
	local s = t - (m*60)
	if m > 0 then
		timetext = string.format("|cff%s%d:%02d|r mins",Crayon:GetThresholdHexColor(m, 3, 6, 10, 20, 30) ,m, floor(s))
	else
		timetext = string.format("|cffff0000%.0f |rsecs", floor(s))
	end
return timetext 
end 

function PoisonReminderFu:OnTextUpdate()
local hasMainHandEnchant, mainHandExpiration, mainHandCharges, hasOffHandEnchant, offHandExpiration, offHandCharges = GetWeaponEnchantInfo()
if hasMainHandEnchant and hasOffHandEnchant then self:SetText("|cff00ff00Poisons are Fine|r") end
if not hasMainHandEnchant and hasOffHandEnchant then self:SetText("|cffff7f00Main Hand Expired!|r") end
if hasMainHandEnchant and not hasOffHandEnchant then self:SetText("|cffff7f00Off Hand Expired!|r") end
if not hasMainHandEnchant and not hasOffHandEnchant then self:SetText("|cffff0000Both Expired!!|r") end
end 